#!/bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#
# Script function
# Provide capabilities to manipulate external processes used by Network Control. These
# includes I-UFM.  This script is called when Network Control is activated or 
# deactivated or when High Availability support is configured.
#
#


IUFM_DIR="/etc/init.d"
NETWORK_CONTORL_DIR="/opt/ibm/director/NetworkControl/bin"


# function to stop I-UFM/Apache via the ufmd stop script
function stopIUFM(){   
    $IUFM_DIR/ufmd stop

    # if ufmha script exists, call it
    if [ -f "$IUFM_DIR/ufmha" ] ; then
      $IUFM_DIR/ufmha stop
    fi
}

# function to start I-UFM/Apache via the ufmd script
function startIUFM(){
    $IUFM_DIR/ufmd start

    # if ufmha is installed, call it
    if [ -f "$IUFM_DIR/ufmha" ] ; then
      $IUFM_DIR/ufmha start
    fi

}


# Main function starts here
#
# Check the parameter passed in
case $1 in 
 "start" ) 
    # start the external processes  I-UFM
    
    # if I-UFM is installed, start it
    if [ -f $IUFM_DIR/ufmd  ] ; then
  	  startIUFM
    fi 
  ;;
  
   
 "stop" )
    # stop the external processes I-UFM
   

    # if I-UFM is installed stop it.  The I-UFM scripts should take care of making sure it is dead
    if [ -f $IUFM_DIR/ufmd  ] ; then
  	  stopIUFM
    fi 
  ;;

  
  * )
    echo "Invalid parameter"
  ;;
esac

    exit 0


