#!/bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END

# 
# 09N6996
#

# Enable logging
SMHA_DEBUG="ON"


#include common exploiter code
EXPLOITER_COMMON_CODE=/opt/ibm/director/ha/bin/include/smha_exploiter_common.sh

if [ -f $EXPLOITER_COMMON_CODE ]; then
    source $EXPLOITER_COMMON_CODE
else
    echo "$PROGNAME:Exploiter common code not found."
    exit 1
fi
#############################################################
# Parameter 1 = path/file name.
# Parameter 2 = file or link.
function print_nofile() {
  Type=${2}
  case ${Type} in
  file)
  	smha_debug "Expected file '$1' does not exist"
  	;;
  link)
  	smha_debug "Expected symbolic link '$1' does not exist"
    ;;
  esac

}

#############################################################

Action=${1}
position=${2}

smha_debug "conf_NC.sh called with ${1} ${2}"

# when configuration is started, "conf" is invoked with "begin", then "end"
# when configuration is terminated, "unconf" is invoked with "begin", then "end"
case ${Action} in
conf)
	if [ "$position" == "begin" ]
	then
	    # Check if I-UFM configuration is correct
        smha_debug "START -- Check NC I-UFM preconditions..."

        filename="/opt/ibm/director/data/ufm/gv_override.cfg"
        if [ ! -f $filename ]
        then
            print_nofile $filename "file"
  			exit 80
		fi

		filename="/mirror0/NetworkControl/ufm-security.properties"
		if [ ! -f $filename ]
		then
 			 print_nofile $filename  "file"
 			 exit 81
		fi

		filename="/opt/ibm/director/proddata/ufm-security.properties"
		if [ ! -L $filename ]
		then
 			 print_nofile $filename "link"
 			 exit 82
		fi

		ufmd_status=`service ufmd status`
		# The command produces output like the following when ISD is active
		# and IUFM is in a good state.
		#
		# Checking for httpd2:                                                running
		# Checking for ufmd process:                                          running
		# Checking for ufmd status:                                           running
		#
		# Verify ufmd status is running.  
		#echo $ufmd_status | grep -Pi "ufmd status:.*running" > /dev/null 2>&1
		echo $ufmd_status | grep -Pi "ufmd status:.*running"
		if [ "$?" -ne "0" ]
		then
 			 smha_debug "ERROR:  ufmd status shows I-UFM is not running."
 			 exit 90
		fi

		# Ensure getStatus returns "Active".
		# NOTE:  This check is only valid if the NC "Service Fabric Provisioning" license 
		# is enabled.  So it should not be run prior to HA setup.
		#get_iufm_status=`smcli getStatus`
		#echo $get_iufm_status | grep -Pi "\"Status\": \"active\""
		#if [ "$?" -ne "0" ]
		#then
		#  smha_debug "ERROR:  smcli getStatus 'Status' is not active."
		#  exit 91
		#fi

		smha_debug "END -- NC I-UFM precondition checks passed."
	fi
    RC=0
    ;;
unconf)
	# if [ "$position" == "end" ]
	# then
		# no action
    # fi
	RC=0
    ;;
upgrade) 
	# no action	
	RC=0
	;;
esac
smha_debug "conf_NC.sh exiting"
exit $RC
