#!/bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#
# Script function
# Called by HA TSA model to start/stop or get the status of the I-UFMD  processes
# used by Network Control
#
SMHA_DEBUG_TSA="ON"

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)

IUFMD_INSTALLED=false 

NETWORK_CONTROL_DIR="/opt/ibm/director/NetworkControl/bin"
IUFMD_DIR="/etc/init.d"
if [ -f $IUFMD_DIR/ufmd  ] ; then
	IUFMD_INSTALLED=true
fi

#### Use a special path for TSA monitoring scripts
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

EXPLOITER_COMMON_CODE=/opt/ibm/director/ha/bin/include/smha_exploiter_common.sh

if [ -f $EXPLOITER_COMMON_CODE ]; then
    source $EXPLOITER_COMMON_CODE
else
    echo "$PROGNAME:Exploiter common code not found."
    exit 1
fi
#############################################################

rcIUFMD=$TSA_UNKNOWN  
  

Action=${1}

case ${Action} in
  start)
    # Start the NC processes
    smha_debug_tsa "NC start requested."
	smha_record_tsa_action $Action NetworkControl "-"
	
    $NETWORK_CONTROL_DIR/ncProcesses.sh start

    #not sure how these could fail.  Status check should detect any issues
    RC=0
    ;;

  stop)
    # stop the NC processes	
    smha_debug_tsa "NC stop requested."
	smha_record_tsa_action $Action NetworkControl "-"
	    
    $NETWORK_CONTROL_DIR/ncProcesses.sh stop
    
    #not sure how these could fail.  Status check should detect any issues
    RC=0
    ;;

  status)
    smha_debug_tsa "NC status requested."

    # check the status of I-UFMD

      $IUFMD_DIR/ufmd status
      statusrc=$?
    
      smha_debug_tsa "I_UFMD status is $statusrc."
    
      case $statusrc in
          0) #Active
              rcIUFMD=${TSA_ONLINE}
              ;;
          *) # 1 UFM not running, Apache running, 2 UFM running, apache not running, 3 neither running
              rcIUFMD=${TSA_OFFLINE}
              ;;    
      esac  

    smha_debug_tsa "rcIUFMD is $rcIUFMD"
    echo  "rcIUFMD is $rcIUFMD"
    
 
    RC=${rcIUFMD}
    
   ;;
esac 

smha_debug_tsa "$PROGNAME $Action: rc=$RC"
smha_record_tsa_action $Action NetworkControl $RC
echo $RC
exit $RC
